@@ -75,10 +75,12 @@ enum XxBoolOpt {
    BOOL_EXIT_IF_NO_CONFLICTS,
    BOOL_SELECT_MERGE,
    BOOL_IGNORE_HORIZONTAL_WS,
+   BOOL_IGNORE_PERHUNK_WS,
    BOOL_FORMAT_CLIPBOARD_TEXT,
    BOOL_IGNORE_ERRORS,
    BOOL_WARN_ABOUT_UNSAVED,
    BOOL_DISABLE_CURSOR_DISPLAY,
+   BOOL_DRAW_PATTERN_IN_FILLER_LINES,
    BOOL_HIDE_CR,
    BOOL_DIRDIFF_IGNORE_FILE_CHANGES,
    BOOL_DIRDIFF_BUILD_FROM_OUTPUT,
@@ -189,6 +191,7 @@ enum XxAccel {
    ACCEL_HORDIFF_SINGLE, 
    ACCEL_HORDIFF_MULTIPLE,
    ACCEL_TOGGLE_IGNORE_HORIZONTAL_WS,
+   ACCEL_TOGGLE_IGNORE_PERHUNK_WS,
    ACCEL_TOGGLE_FORMAT_CLIPBOARD_TEXT,
    ACCEL_IGNORE_FILE_NONE,
    ACCEL_IGNORE_FILE_LEFT,
@@ -261,6 +264,7 @@ enum XxColor {
    COLOR_BACKGROUND,
    COLOR_CURSOR,
    COLOR_VERTICAL_LINE,
+   COLOR_TEXT_SELECTION,
 
    COLOR_LAST // Not a real resource.
 };
@@ -501,10 +505,12 @@ public:
    void setTag( XxTag, const QString& );
    // </group>
 
-   // Get/set clipboard format string.
+   // Get/set clipboard selection or line format string.
    // <group>
-   const QString& getClipboardFormat() const;
-   void setClipboardFormat( const QString& format );
+   const QString& getClipboardHeadFormat() const;
+   void setClipboardHeadFormat( const QString& format );
+   const QString& getClipboardLineFormat() const;
+   void setClipboardLineFormat( const QString& format );
    // </group>
 
    // Get/set type of horizontal diffs.
@@ -606,7 +612,8 @@ private:
    uint         _overviewSepWidth;
    uint         _verticalLinePos;
    QString      _tags[ TAG_LAST ];
-   QString      _clipboardFormat;
+   QString      _clipboardHeadFormat;
+   QString      _clipboardLineFormat;
    XxIgnoreFile _ignoreFile;
    XxHordiff    _hordiffType;
    uint         _hordiffMax;
